==> plugin-android-0.0.9-sources.jar: com/zoyi/channel/plugin/android/activity/chat/viewholder/ManagerMessageHolder.java <==
package com.zoyi.channel.plugin.android.activity.chat.viewholder;

import android.content.Context;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.listener.OnMessageClickListener;
import com.zoyi.channel.plugin.android.activity.chat.model.ChatMessageItem;
import com.zoyi.channel.plugin.android.model.rest.ProfileEntity;
import com.zoyi.channel.plugin.android.util.ResUtils;
import com.zoyi.channel.plugin.android.view.layout.AvatarLayout;

/**
 * Created by mika on 2016. 12. 9..
 */
public class ManagerMessageHolder extends ChatMessageHolder {
  Context context;
  AvatarLayout avatar;
  TextView textName;
  LinearLayout contentList;

  public ManagerMessageHolder(
      View itemView,
      OnMessageClickListener listener) {
    super(itemView, listener);

    context = itemView.getContext();
    avatar = (AvatarLayout) itemView.findViewById(R.id.message_avatar);
    textName = (TextView) itemView.findViewById(R.id.message_name);
    contentList = (LinearLayout) itemView.findViewById(R.id.message_addon_content);
  }

  protected void setProfile(ProfileEntity profile) {
    avatar.set(profile);
    if (profile == null) {
      textName.setText(ResUtils.getString(context, "ch.unknown"));
    } else {
      textName.setText(profile.getName());
    }
  }

  public void set(ChatMessageItem item, ProfileEntity profile, boolean isContext) {
    super.set(item.getMessage(), isContext);
    contentList.setVisibility(View.GONE);
    setProfile(profile);
  }
}

==> plugin-android-2.3.1-sources.jar: com/zoyi/channel/plugin/android/activity/chat/viewholder/ManagerMessageHolder.java <==
package com.zoyi.channel.plugin.android.activity.chat.viewholder;

import android.content.Context;
import android.view.View;
import android.widget.TextView;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.activity.chat.ChatDataDictionary;
import com.zoyi.channel.plugin.android.activity.chat.listener.OnMessageClickListener;
import com.zoyi.channel.plugin.android.activity.chat.model.ChatMessageItem;
import com.zoyi.channel.plugin.android.model.interfaces.ProfileEntity;
import com.zoyi.channel.plugin.android.util.ResUtils;
import com.zoyi.channel.plugin.android.view.layout.AvatarLayout;

/**
 * Created by mika on 2016. 12. 9..
 */
public class ManagerMessageHolder extends ChatMessageHolder {

  Context context;
  AvatarLayout avatar;
  TextView textName;

  public ManagerMessageHolder(
      View itemView,
      OnMessageClickListener listener) {
    super(itemView, listener);

    context = itemView.getContext();
    avatar = (AvatarLayout) itemView.findViewById(R.id.message_avatar);
    textName = (TextView) itemView.findViewById(R.id.message_name);
  }

  protected void setProfile(ProfileEntity profile) {
    avatar.set(profile);
    if (profile == null) {
      textName.setText(ResUtils.getString(context, "ch.unknown"));
    } else {
      textName.setText(profile.getName());
    }
  }

  public void set(ChatMessageItem item, boolean isContext) {
    ProfileEntity profile = ChatDataDictionary.getInstance()
        .getProfile(item.getPersonType(), item.getPersonId());

    super.set(item.getMessage(), isContext);
    setProfile(profile);
  }
}
